<?php

namespace Drupal\testsuite;

use Symfony\Component\HttpFoundation\Request;

/**
 * Provides an interface defining a testsuite entity.
 */
interface TestInterface {

  /**
   * Gets the module name.
   *
   * @return string
   *   The module name.
   */
  public function getModuleName();

  /**
   * Gets the menu name.
   *
   * @return string
   *   The menu item name.
   */
  public function getMenuName();

  /**
   * Gets the test name.
   *
   * @return string
   *   If the test succeeded or failed.
   */
  public function getName();

  /**
   * Gets the test description.
   *
   * @return string
   *   If the test succeeded or failed.
   */
  public function getDescription();

  /**
   * Runs the test and returns if the test succeeded or failed.
   *
   * @param Symfony\Component\HttpFoundation\Request $request
   *   The request object.
   *
   * @return string
   *   Success or Test Passed if the test succeeded.
   *   Failed and the eroors if the test failed.
   */
  public function runTest(Request $request);

}
